@@ -3,8 +3,10 @@
 /* Returns the block size used by the kernel sound driver.  The big
    buffer will be partitioned into chunks of this size. */
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/ioctl.h>
 #include <linux/soundcard.h>
 
@@ -12,13 +14,10 @@
 
 int get_au_blksz(int audio_fd)
 {
-  long blocksize;
+  int blocksize;
 
-  if ( ioctl(audio_fd, SNDCTL_DSP_GETBLKSIZE, &blocksize) == -1 ) {
-    fprintf(stderr, "%s: SNDCTL_DSP_GETBLKSIZE ioctl failed: ", progname);
-    perror("");
-    exit(EXIT_FAILURE);
-  }
+  if ( ioctl(audio_fd, SNDCTL_DSP_GETBLKSIZE, &blocksize) == -1 )
+    err_die("SNDCTL_DSP_GETBLKSIZE ioctl failed: %s\n", strerror(errno));
 
   return blocksize;
 } 
